@@ -1,10 +1,7 @@
-import datetime
 import logging
 
 import discord
 
-from carim_discord_bot import config
-
 log = logging.getLogger(__name__)
 
 
@@ -27,7 +24,4 @@ def build_embed(title=None, message=None):
         title = None
     embed_args = dict(title=title, description=message)
     embed = discord.Embed(**embed_args)
-    if config.get().include_timestamp:
-        timestamp = datetime.datetime.now(tz=datetime.timezone.utc).isoformat()
-        embed.set_footer(text=timestamp)
     return embed
